@@ -312,10 +312,24 @@ def analyze(model):
     # TODO: JSON data
 
     # Get basic data
+    triangle_count = 0
     vertex_count = 0
+    rendered_triangle_count = 0
     for m in model.meshes:
+        mesh_triangle_count = 0
         for p in m.primitives:
             vertex_count += p.positions.count
+            if p.mode is None or p.mode == 4:
+                mesh_triangle_count += int((p.indices.count if p.indices else p.positions.count) / 3)
+            else:
+                print(f'Unsupported primitive mode: {p.mode}')
+        triangle_count += mesh_triangle_count
+        mesh_usage_count = 0
+        for n in model.nodes:
+            if n.mesh is m:
+                mesh_usage_count += 1
+        rendered_triangle_count += mesh_usage_count * mesh_triangle_count
+
     # Get basic data
     instanced_vertex_count = 0
     counted_prims = set()
@@ -346,8 +360,10 @@ def analyze(model):
                 (label, count, recommended, count < recommended)
                 for label, count, recommended in
                 [
-                    ("Mesh Vertices", vertex_count, 30000),
-                    ("Instanced Vertices", instanced_vertex_count, 30000),
+                    ("Mesh Vertices", vertex_count, 30_000),
+                    ("Instanced Vertices", instanced_vertex_count, 30_000),
+                    ("Triangle Count", triangle_count, 100_000),
+                    ("Rendered Triangle Count", rendered_triangle_count, 100_000),
                     ("Meshes", mesh_count, 10),
                     ("Materials", mat_count, 10),
                     ("Animation Targets", animation_target_count, 254),
